@@ -48,16 +48,18 @@ class gitricsGroupIssues(GitlabGroup):
         # check for data
         if items:
 
-            # get notes
-            for i in items:
-                i.notes = i.extract_notes()
-
             # enrich
             self.issues = self.enrich(items)
 
             # build network
             self.nested = self.nest(self.issues)
 
+            # get notes
+            for i in items:
+                i.notes = i.extract_notes()
+                i.percent_complete = 0
+                #i.graph_depth = nx.shortest_path_length(self.nested, 0)[i.id]
+
         else:
             self.issues = items
             self.nested = None
