@@ -2,14 +2,14 @@ import time
 
 from gitrics import configuration
 
-from glapi.project.project import GitlabProject
+from glapi.project import GitlabProject
 
 class gitricsProjectEvents(GitlabProject):
     """
     gitricsProjectEvents is a collection of Gitlab Project Events modified and enriched for gitrics ecosystem.
     """
 
-    def __init__(self, project_id: str = None, project: dict = None, date_start: str = configuration.DATE_START, date_end: str = configuration.DATE_END, token: str = None, version: str = configuration.GITLAB_API_VERSION):
+    def __init__(self, project_id: str = None, project: dict = None, date_start: str = None, date_end: str = None, event_actions: list = None, token: str = None, version: str = configuration.GITLAB_API_VERSION):
         """
         Args:
             date_end (string): iso 8601 date value
@@ -33,6 +33,7 @@ class gitricsProjectEvents(GitlabProject):
 
         # get events
         self.events = self.extract_events(
+            actions=event_actions if event_actions else list(),
             date_end=date_end,
             date_start=date_start
         )
